@@ -23,9 +23,9 @@ def reg_find(exp, text):
     result = re.search(exp, text)
     if not result:
         return None
-    ret = list(result.groups())
+    ret = result.groups()
     if not ret:
-        ret = [result.group()]
+        ret = result.group()
     return ret
 
 
